@@ -426,24 +426,9 @@ class Update(MethodsInterface):
                     working_host, url, rpath, revision = self.checkUrl(host, host_urls, repname, dv, git)
                     if working_host:
                         break
-            # --------------DEPRECATED--------------#
-            if not all([working_host, rpath, revision, url]):
+            if not working_host:
                 dv.Write('cl_update_rep_hosting', ' ')
-                if not dv.Get("cl_update_rep_url"):
-                    raise UpdateError(_("Git is unavailable"))
-                url, rpath, revision = (
-                    dv.Select(["cl_update_rep_url", "cl_update_rep_path",
-                               "cl_update_rep_rev"],
-                              where="cl_update_rep_name", eq=repname, limit=1))
-
-                if not url or not rpath:
-                    raise UpdateError(_("Configuration variables for repositories "
-                                        "are not setup"))
-                git = self.getGit()
-                if not git.checkUrl(url):
-                    raise UpdateError(_("Git %s is unavailable") % url)
-
-
+                raise UpdateError(_("Git is unavailable"))
             if working_host:
                 dv.Write('cl_update_rep_hosting', working_host)
 
@@ -1496,7 +1481,7 @@ class Update(MethodsInterface):
                 self.clVars.Get("update.cl_update_portage_binhost_path"))
             if path.exists(binhost_fn):
                 os.unlink(binhost_fn)
-        if self.clVars.GetBool('cl_update_binhost_set') and self.clVars.GetBool('cl_update_use_migration_host'):
+        if self.clVars.GetBool('update.cl_update_binhost_set') and self.clVars.GetBool('cl_update_use_migration_host'):
             self.clVars.Write('cl_update_binhost', self.clVars.Get('cl_update_save_cur_binhost') , location="system")
         return False
 
